==> qtjambi-serialbus-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiSerialBus/QCanBus_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtSerialBus/qcanbus.h>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtCore/QStringList>
#include <QtCore/QList>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtCore/qstring.h>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBus::availableDevices(QString,QString*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_availableDevices_1native_1cref_1QString_1QString_1ptr_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring plugin0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::availableDevices(QString,QString*)const", __qt_this)
        QString  __qt_plugin0 = qtjambi_cast<QString >(__jni_env, plugin0);
        QString errorMessage1;
        QString* __qt_errorMessage1 = &errorMessage1;
        QList<QCanBusDeviceInfo> __qt_return_value = __qt_this->availableDevices(__qt_plugin0, __qt_errorMessage1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);


        if(!errorMessage1.isEmpty()){
            Java::QtSerialBus::QCanBusException::throwNew(__jni_env, errorMessage1 QTJAMBI_STACKTRACEINFO );
        }
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::createDevice(QString,QString,QString*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_createDevice_1native_1cref_1QString_1cref_1QString_1QString_1ptr_1constfct__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring plugin0,
 jstring interfaceName1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::createDevice(QString,QString,QString*)const", __qt_this)
        QString  __qt_plugin0 = qtjambi_cast<QString >(__jni_env, plugin0);
        QString  __qt_interfaceName1 = qtjambi_cast<QString >(__jni_env, interfaceName1);
        QString errorMessage2;
        QString* __qt_errorMessage2 = &errorMessage2;
        QCanBusDevice* __qt_return_value = __qt_this->createDevice(__qt_plugin0, __qt_interfaceName1, __qt_errorMessage2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);


        if(!__qt_return_value && !errorMessage2.isEmpty()){
            Java::QtSerialBus::QCanBusException::throwNew(__jni_env, errorMessage2 QTJAMBI_STACKTRACEINFO );
        }
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::plugins()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_plugins_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::plugins()const", __qt_this)
        QStringList __qt_return_value = __qt_this->plugins();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::instance()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_instance__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBus::instance()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QCanBus* __qt_return_value = QCanBus::instance();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QCanBus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QCanBus>("QCanBus", "io/qt/serialbus/QCanBus");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QCanBus::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiSerialBus/QCanBus_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanbus.h>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtCore/QStringList>
#include <QtCore/QList>
#include <QtSerialBus/qcanbusdeviceinfo.h>
#include <QtCore/qstring.h>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qthread.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qmetaobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBus::availableDevices(QString,QString*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_availableDevices_1native_1cref_1QString_1QString_1ptr_1constfct__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring plugin0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::availableDevices(QString,QString*)const", __qt_this)
        QString  __qt_plugin0 = qtjambi_cast<QString >(__jni_env, plugin0);
        QString errorMessage1;
        QString* __qt_errorMessage1 = &errorMessage1;
        QList<QCanBusDeviceInfo> __qt_return_value = __qt_this->availableDevices(__qt_plugin0, __qt_errorMessage1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);


        if(!errorMessage1.isEmpty()){
            Java::QtSerialBus::QCanBusException::throwNew(__jni_env, errorMessage1 QTJAMBI_STACKTRACEINFO );
        }
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::createDevice(QString,QString,QString*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_createDevice_1native_1cref_1QString_1cref_1QString_1QString_1ptr_1constfct__JLjava_lang_String_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring plugin0,
 jstring interfaceName1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::createDevice(QString,QString,QString*)const", __qt_this)
        QString  __qt_plugin0 = qtjambi_cast<QString >(__jni_env, plugin0);
        QString  __qt_interfaceName1 = qtjambi_cast<QString >(__jni_env, interfaceName1);
        QString errorMessage2;
        QString* __qt_errorMessage2 = &errorMessage2;
        QCanBusDevice* __qt_return_value = __qt_this->createDevice(__qt_plugin0, __qt_interfaceName1, __qt_errorMessage2);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);


        if(!__qt_return_value && !errorMessage2.isEmpty()){
            Java::QtSerialBus::QCanBusException::throwNew(__jni_env, errorMessage2 QTJAMBI_STACKTRACEINFO );
        }
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::plugins()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_plugins_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QCanBus *__qt_this = QtJambiAPI::objectFromNativeId<QCanBus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBus::plugins()const", __qt_this)
        QStringList __qt_return_value = __qt_this->plugins();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCanBus::instance()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBus_instance__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBus::instance()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QCanBus* __qt_return_value = QCanBus::instance();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QCanBus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QCanBus>("QCanBus", "io/qt/serialbus/QCanBus");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QCanBus::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
